#
# spec file for package python-holidays
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-holidays
Version:        0.72
Release:        1.1
Summary:        Python library for generating holidays on the fly
License:        MIT
URL:            https://github.com/vacanza/python-holidays
Source:         https://github.com/vacanza/python-holidays/archive/refs/tags/v%{version}.tar.gz#/holidays-%{version}.tar.gz
BuildRequires:  %{python_module convertdate}
BuildRequires:  %{python_module hijri-converter >= 2.2}
BuildRequires:  %{python_module importlib-metadata if %python-base < 3.10}
BuildRequires:  %{python_module korean-lunar-calendar}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module polib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
A Python library for generating country, province and state specific sets of holidays on the fly.
It makes determining whether a specific date is a holiday possible.

%prep
%setup -q -n holidays-%{version}

%build
scripts/l10n/generate_mo_files.py
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
sed -i '/"--cov-fail-under=100",/d' pyproject.toml
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES.md README.md
%{python_sitelib}/holidays
%{python_sitelib}/holidays-%{version}.dist-info

%changelog
* Mon May 12 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.72
  * Add Sao Tome and Principe holidays
  * Add Trinidad and Tobago holidays
  * Fix TestClosestHoliday current date handling
  * Fix typography: replace U+2019 with "'" and U+2013 with '-'
  * Update Canada holidays: add historical holidays
  * Update Ethiopia holidays: official source namings, WORKDAY category
  * Update India holidays: add missing Tamil Nadu holidays
  * Update README: add Snyk package health badge
  * Update Singapore holidays: 2025 Polling Day on May 3rd
  * Update Taiwan holidays: test case refactor
  * Update documentation build process
  * Update documentation tests: add AUTHORS.md checking
  * Add missing subdivisions aliases
  * Disable v1 incompatibility warning
  * Docstring cleanup for Indochinese countries
  * Extend Chinese Lunisolar calendar support
  * Rename AUTHORS.md to CONTRIBUTORS
* Mon May  5 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.71
  * Add French Southern Territories holidays
  * Add Oman holidays
  * Add Sierra Leone holidays
  * Add Suriname holidays
  * Update .po files generator
  * Update .po files generator
  * Update BY.po files
  * Update Pakistan holidays: add Youm-e-Takbeer holiday
  * Update Python latest supported version format
  * Update RELEASE.md
  * Update South Korea holidays: add 2025 Presidential Election Day
  * Update l10n related documentation: detailed explain of
    language parameter behavior
  * Update mypy configuration
  * Add FUNDING.yml
- Update to 0.70
  * Add iCalendar export support
  * Add Antigua and Barbuda holidays
  * Add Fiji holidays
  * Add Guinea holidays
  * Add Ivory Coast holidays
  * Add Qatar holidays
  * Update Argentina holidays: add categories and subdivisions support
  * Update India holidays: Hindi l10n fixes
  * Update Pakistan holidays: add 2023-2024 exact dates
  * Update Pakistan holidays: add l10n support (en_PK, en_US, ur_PK
  * Update Philippines holidays: 2025 Eid'l Fitr
  * Update Philippines holidays: adjust Bonifacio Day for 2023
  * Update README.md badges
  * Update Timor-Leste holidays: add en_TL, th l10n, update en_US l10n
  * Update HolidayBase::pop_named: add support for more lookup types
  * Update _ThaiLunisolar and ThaiCalendarHolidays documentation
  * Update pyproject.toml: align with PEP 639 metadata format
  * Update release notes generator
  * Update tests requirements
  * Added commit SHAs instead of versions
  * Adjust project files after migration to MkDocs
  * Migrate Documentation from Sphinx to MkDocs
  * Reformat .po files
  * Reformat BY.po files
- Update to 0.69
  * Introduce HolidayBase methods for proper serialization
  * Add Macau holidays
  * Update IN holidays and localization
  * Update Poland holidays: add de localization
  * Fix l10n handling
  * Update Hong Kong holidays: standardizes en_US l10n with China's and
    Macau's implementation
  * Update Indonesia holidays: 2031-2050 Day of Silence (Nyepi) data, migrate
    to BalineseSakaCalendarHolidays
  * Update Philippines holidays: 2025 Eid'l Fitr and Eid'l Adha Tentative Date
  * Update Taiwan holidays: add categories support
  * Update Timor Leste holidays: fix 2025 Islamic holidays
  * Update US holidays: add federal holidays as GOVERNMENT category
  * Update US holidays: аdd additional MI state holidays
  * Update IslamicHolidays: add an option whether to add estimation label
    to holiday name
- Update to 0.68
  * Fix 2025 Chinese Calendar's Birthday of Buddha
  * Update AZ holidays: add 2025 substituted holidays
  * Update Kenya holidays, add l10n support
  * Update Malaysia holidays
  * Update Zenodo record URL in README
  * Update issue templates
  * Update l10n scripts
  * Add .coderabbit.yaml
* Mon Feb 24 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.67
  * Add Saint Lucia holidays
  * Add Tuvalu holidays
  * Update Greenland holidays l10n
  * Update Hong Kong holidays: add l10n support
  * Update Hong Kong holidays: fix `th` l10n typo
  * Update Panama holidays, add l10n support
  * Update README: add DOI
  * Update United Kingdom & Isle of Man holidays: add l10n support
  * Update internal scripts
  * Update subdivision names for Presidents' Day in the United States
  * Add Python syntax check with ruff-pyupgrade rules
  * Add make script for Windows
  * Check .mo rather than .po files in TestListLocalizedEntities
  * Implement HolidayBase::get_closest_holiday functionality
  * Unify certain holidays names translation
* Tue Feb 11 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.66
  * Add Sri Lanka holidays
  * Fix typo in CONTRIBUTING.rst
  * Update Czechia holidays
  * Update Germany holidays: add Corpus Christi in CATHOLIC category
  * Update Iceland holidays: add HALF_DAY holidays
  * Update Iran holidays
  * Update PR exclusion logic
  * Update Slovakia holidays: Constitution Day is working day since 2024
  * Update Slovenia holidays
  * Update Sweden holidays: fix All Saints' Day
  * Update Thailand holidays: refactor Royal Ploughing Ceremony code
  * Update United Arab Emirates holidays: add `th` l10n, exact 2017-2025 entries
  * Update Vatican City holidays: add missing holidays, l10n support
  * Update automatic snapshots update workflow
  * Update some holidays Ukrainian translations
  * Add Israel holidays localization: th
  * Add West Frisian language
  * Pin CI/CD Ubuntu version
  * Remove .po files from distribution bundles
- from version 0.65
  * Update Afghanistan and Iran holidays: change weekend to FRI-SAT and FRI respectively
  * Update Afghanistan holidays
  * Update South Korea holidays: 2025 temporary public holidays
  * Update ruff from v0.8.6 to v0.9.1
  * Add faster date parsing from strings in ISO 8601 format
  * Add signed artifacts path
- from version 0.64
  * Introduce `common.WorkingDayTests` class
  * Refactor XNYS holidays: standardize US market holidays days of mourning entries
  * Add Afghanistan holidays
  * Add `HebrewCalendarHolidays` to holidays groups, refactor Israel holidays
  * Update "Set up Python" to use 3.13
  * Update Belarus holidays: add ru & th l10n, 2024-2025 substituted holidays
  * Update El Salvador holidays, add l10n support
  * Update Montenegro holidays, add l10n support
  * Update Poland holidays: add Christmas Eve holiday since 2025
  * Update Ukraine holidays in 1991
  * Update XNYS: add a Day of Mourning for President Jimmy Carter
  * Update working days calculation
  * Add Norway holidays localization: th
  * Add Russia holidays localization: th
  * Add Ukraine holidays localization: th
  * Sign release artifacts using Sigstore
- from version 0.63
  * Update CI/CD trigger section
  * Update KZ holidays: add 2025 special holidays
  * Update Thailand holidays: extend support year down to 1914
  * Add French subdivision aliases
  * Align financial markets MIC codes with ISO 10383
  * Enforce 100%% test coverage
  * Inline single-use variables, update .py files formatting
- from version 0.62
  * Introduce start/end year for entity
  * Add Guernsey holidays
  * Update AZ holidays: add 2025 special holidays
  * Update Argentina holidays: Add 2025 Bridge Public Holidays
  * Update CA holidays: Nunavut Day is NU public holiday since 2020
  * Update Finland holidays: fix Independence Day appearing pre-1917
  * Update Paraguay holidays
  * Update Timor Leste holidays: Add 2024 Nov 29 Special Holiday
  * Update pyproject.toml: clarify project summary
  * Add SECURITY.md
- from version 0.61
  * Add financial markets l10n support
  * Refactor some `if len(container)...` cases to `if container...`
  * Add "Brasil, Bolsa, Balcão" ([B]³) holidays
  * Update Brazil holidays, add l10n support
  * Update Brunei holidays: 1998-2003, 2006-2025 exact dates
  * Update CH holidays: rename Neujahrestag to Neujahrstag
  * Update Cambodia holidays: add Peace Day in Cambodia
  * Update China holidays in 2025
  * Update Thailand holidays: 2025-2026 Bridge Public Holidays
  * Update Unites States holidays: remove Columbus Day from countrywide holidays
  * Update `TestCase::assertLocalizedHolidays`: add subdivisions holidays support
  * Update helpers::_normalize_arguments, add helpers tests
  * Update ruff configuration: add Pylint errors check
  * Add Europe Day to InternationalHolidays
  * Add Portugal subdivision aliases
- from version 0.60
  * Refactor Australia tests
  * Refactor Cambodia and Laos test cases
  * Refactor Canada tests
  * Refactor United States tests
  * Refactor v1 incompatibility warning
  * Update the Philippines holidays: add `en_PH`, `en_US`, `fil`, `th` localization
  * Fix `make l10n` removing loc comment for Asarnha Bucha
  * Fixed Thai Calendar test case coverage
  * Improve .po files "Language-Team" header consistency
  * Update Albania holidays, add l10n support
  * Update Australia holidays: remove `Adelaide Cup Day` holiday pre-1973 for South Australia
  * Update CONTRIBUTING.rst
  * Update Germany holidays: add East German Uprising Day 2028 in Berlin
  * Update Indonesia holidays: `th` localization, more refractor
  * Update Indonesia holidays: add 2024 Local Election, exact historic dates from 1963 onwards
  * Update Spain holidays in 2025
  * Update Thailand holidays in 2025
  * Update Timor-Leste holidays
  * Update United States holidays: Alaska state holidays correction
  * Simplify PR template
- from version 0.59
  * Update Vietnam holidays: add `th` localization
  * Update Germany holidays: add Liberation from Nazi Regime Day 2025 in Berlin
  * Update Johor (Malaysia) and United Arab Emirates `weekend` observance, cleanup others
  * Update Vietnam holidays
  * Update `InternationalHolidays::_add_world_war_two_victory_day()` method
  * Update `holidays` package metadata
  * Update metadata Python versions
  * Add `EasternCalendarHolidays` to holidays groups
  * Drop Python 3.8 support
  * Satisfy mypy requirements
- from version 0.58
  * Add Congo holidays
  * Add Saint Kitts & Nevis holidays
  * Add Vietnamese translation of VietNam holidays
  * Update Kazakhstan holidays: add substituted holidays, localization
  * Update Malaysia holidays: add `th` localization
  * Update Singapore holidays: add `en_SG`, `en_US`, `th` localization
  * Update Sweden holidays: add `th` localization
  * Update Azerbaijan holidays in 2024
  * Update Curaçao holidays: add HALF_DAY holidays
  * Update Japan holidays
  * Update Nicaragua holidays
  * Update Taiwan holidays
  * Update US holidays: American Samoa holidays
  * Update United States holidays: fix Washington's Birthday in GA & IN
  * Update `ci` label configuration
  * Update apostrophes: change `’` to `'`
  * Update working day related calculations
  * Add @PPsyrius to CODEOWNERS
  * Move to `holidays` from `python-holidays`
  * Remove deprecated `fix-encoding-pragma`, add `pyupgrade`
- from version 0.57
  * Update Australia holidays: add `en_AU`, `en_US`, `th` localization
  * Fix some docstrings
  * Update Australia holidays: fix Christmas Day in ACT
  * Update Germany holidays: add `th` localization, deprecated non-standard ISO code, add subdivision aliases
  * Update Jersey holidays
  * Update South Korea holidays: add Armed Forces Day in 2024
  * Update examples to reflect recent holidays changes
  * Add Frances Xavier Cabrini Day for United States, Colorado
  * Extend `_ThaiLunisolar` calendar support to 2157
  * Unify en_US Islamic holidays name translation
- from version 0.56
  * Refactor Lao New Year holidays
  * Add 1991-2022 Russian substituted holidays
  * Add Dominica holidays
  * Add Haiti holidays
  * Change "St." to "Saint" in holidays names
  * Update Brunei Darussalam islamic holidays for 2024
  * Update Cambodian holidays for 2024
  * Update Dominican Republic holidays: fix Restoration Day
  * Update HU: add 2025 substituted holidays
  * Update Philippines holidays
  * Update SBOM artifact path
  * Update Snapshot for 0.55 changes
  * Update `numpy` test requirements
  * Update pyproject.toml: remove `target-version` from tool.ruff
  * Add Easter Tuesday to Christian holidays group
  * Add New Zealand Subdivision Aliases (`EN`, `MI`, HASC)
  * Add PR labeler
  * Add Python 3.13 (beta) to CI/CD
  * Add automatic snapshots update workflow
  * Migrate deprecated Bosnia-Herzegovina subdivisions to subdivision aliases
  * Migrate deprecated Italy subdivisions to subdivision aliases
  * Migrate deprecated United Kingdom subdivisions to subdivision aliases
  * Restore Malaysia's 3-letter code as subdivisions aliases
  * Standardize snapshot names
- Add sed command to strip "--cov-fail-under=100" from pytest options
- Adjust upstream source name in spec file
- Use Python 3.11 on SLE-15 by default
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.56:
  * Refactor Lao New Year holidays
  * Add 1991-2022 Russian substituted holidays
  * Add Dominica holidays
  * Add Haiti holidays
  * Change "St." to "Saint" in holidays names
  * Update Brunei Darussalam islamic holidays for 2024
  * Update Cambodian holidays for 2024
  * Update Dominican Republic holidays: fix Restoration Day
  * Update HU: add 2025 substituted holidays
  * Update Philippines holidays
  * Update SBOM artifact path
  * Update Snapshot for 0.55 changes
  * Update `numpy` test requirement
  * Update pyproject.toml: remove `target-version` from tool.ruff
  * Add Easter Tuesday to Christian holidays group
  * Add New Zealand Subdivision Aliases (`EN`, `MI`, HASC)
  * Add PR labeler
  * Add Python 3.13 (beta) to CI/CD
  * Add automatic snapshots update workflow
  * Migrate deprecated Bosnia-Herzegovina subdivisions to
    subdivision aliases
  * Migrate deprecated Italy subdivisions to subdivision aliases
  * Migrate deprecated United Kingdom subdivisions to subdivision
    aliases
  * Restore Malaysia's 3-letter code as subdivisions aliases
  * Standardize snapshot names
  * Add Samoa holidays
  * Fix misleading France subdivision
  * Update CI/CD: add CodeQL workflow
  * Update CI/CD: simplify gh release upload
  * Update Github release upload process
  * Update SG: add 2025 official holidays
  * Update UA: move martial law holidays to WORKDAY category
  * Update utils.py
  * Add special weekends format for certain countries
    @PPsyrius, @arkid15r)
  * Implement simple CycloneDX SBOM generation
  * Add Mauritania holidays
  * Fix Malawi tests
  * Update CI/CD pip caching
  * Update FI: add unofficial holidays
  * Update Finland holidays l10n
  * Update PR template
  * Update RU: add 2025 substituted holidays
  * Update docs requirements: revert sphinx to v7.4.7
  * Add documentation build test to CI/CD
  * Don't run tests on Github readonly queue push events
  * Drop PyPy support
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- update to 0.53:
  * Update Chile holidays: add bank holidays
  * Extend HolidayBase::__setitem__ to handle names including '; '
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- re-apply rudi's fix for generating translations
  need to generated and installed, running at %%check produces an
  incomplete package, not able to work
* Wed Jun 19 2024 Adrian Schröter <adrian@suse.de>
- update to 0.51:
  * Update Aruba and Curaçao holidays l10n (split locales) (#1827 by @KJhellico)
  * Update Brazil holidays: add new Nov 20 holiday (#1832 by @KJhellico)
  * Update CI/CD job concurrency (#1823 by @arkid15r)
  * Update CI/CD job concurrency (#1830 by @arkid15r)
  * Update README.rst (#1828 by @arkid15r)
  * Update ruff configuration (#1819 by @arkid15r)
  * Align India subdivisions with ISO 3166-2 (#1821 by @KJhellico)
  * Migrate to codecov.io (#1818 by @arkid15r)
  * Narrow down ignored warnings (#1816 by @arkid15r)
  * Refactor some holidays with uncommon rules (#1807 by @KJhellico)
  * Add Greenland holidays (#1811 by @Klintrup, @arkid15r)
  * Fix docs: update Italy docstring (#1808 by @arkid15r)
  * Update Italy holidays (#1805 by @KJhellico)
  * Add 2024 Russian Substituted Holidays (#1799 by @PPsyrius)
  * Add Georgian government holiday for May 17, 2024 (#1802 by @PPsyrius, @arkid15r)
  * Add v1 future incompatibility warning (#1801 by @arkid15r)
  * Migrate Japan holidays to ObservedHolidayBase (#1810 by @KJhellico)
  * Synchronize entity dynamic imports (#1794 by @Izzette)
  * Add IFEU holidays (#1792 by @benjfield, @arkid15r)
  * Update Hong Kong holidays (#1767 by @KJhellico, @arkid15r)
  * Update Malaysia holidays (#1791 by @KJhellico)
  * Update observed rules: add holiday removal support (#1796 by @arkid15r)
  * Address numpy int argument conversion issue (#1782 by @arkid15r)
  * Replace `datetime::timedelta` with custom function (#1785 by @KJhellico)
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.48:
  * Introduce workdays calculation support
  * Refactor `HolidayBase::__getattr__`: speed up _add_holiday_*
    methods
  * Add Palau holidays
  * Update Greece holidays: move 2024 Labor Day to May 7
  * Update Timor-Leste holidays
  * Update United States holidays: fix Confederate Memorial Day
    in MS
  * Update badges in README
  * Update CI/CD: fix macOS Python versions
  * Extend HolidayBase::_add_holiday family methods with Easter
    support
  * Prioritize entity default holiday category processing
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.47:
  * Refactor some sequential holidays
  * Add Jordan holidays
  * Change contributors badge placement
  * Update Australia holidays: fix Sovereign's Birthday dates in
    WA
  * Update Eid al-Fitr 2024 dates
  * Update European Central Bank holidays
  * Update Poland holidays: fix Ascension Day
  * Update South Africa holidays: add public holiday on May 29,
    2024
  * Update contributing guidelines
* Tue Apr  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.46:
  * Fix Romanian language strings: replace U+015F with proper
    U+0219
  * Update (c) in file headers and LICENSE
  * Update Australia holidays
  * Update Makefile clean action
  * Update US tests: Day After Thanksgiving
  * Update United Kingdom holidays: fix observed New Year's Day
    in Scotland
  * Update tests: use assertIsInstance
  * Fix README layout (attempt 1)
  * Add file header pre-commit check
  * Add package build tests
  * Unify file headers after recent update
* Tue Mar 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.45:
  * Add Python 3.12 support
  * Add Kuwait holidays
  * Add Seychelles holidays
  * Fix SonarCloud security hotspots
  * Update Mexico holidays
  * Update Ethiopia holidays
  * Update Ukrainian translations (proper apostrophe)
  * Update snapshots: Portugal holidays
  * Add `UNOFFICIAL` category for the United States
  * Introduce subdivisions aliases
  * Update Ireland holidays
  * Update Portugal holidays: fix Carnival date
  * Update Taiwan holidays
  * Update Thailand holidays: add Bridge Public Holiday on Apr 12, 2024
- Add missing BuildRequires on importlib-metadata.
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.42:
  * Add Ghana holidays
  * Add Jersey holidays
  * Update Costa Rica holidays
  * Update Croatia holidays
  * Update Greece holidays
  * Update Switzerland holidays
  * Update United Arab Emirates holidays
  * 2020 China calendar discrepancies fix
  * Add United Kingdom's Whit Monday holidays for pre-1971 years
  * Unify common holidays name translation
  * Use current version for release notes generation
* Tue Jan 23 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.41:
  * Introduce observed_estimated_label
  * Update Argentina holidays
  * Update Cyprus holidays
  * Update Malaysia holidays
  * Update Paraguay holidays
  * Update Thailand holidays
  * Add Papua New Guinea holidays
  * Fix United States and Guam holidays
  * Extend native holiday categories support
  * Update NYSE holidays: fix New Year's Day observed
  * Update Netherlands holidays: fix Liberation Day
  * Add categories and subdivisions support to special observed holidays
  * Add categories and subdivisions support to substituted holidays
  * Update Israel holidays
  * Update Ukraine holidays
  * Migrate NYSE holidays to ObservedHolidayBase
  * Add special holidays per subdivisions support
  * Add special_holidays_observed support
  * Add Bahamas holidays
  * Add Timor-Leste holidays
  * Add Tonga holidays
  * Update Portugal holidays: add holiday categories
  * Add Maldives holidays
  * Add Tanzania holidays
  * Implement Tanzania `StaticHolidays`
  * Add Laos holidays
  * Update Belarus holidays: add substituted holidays
  * Update NYSE holidays: fix Juneteenth National Independence Day start year
  * Update Spain holidays
  * Add merge queue support
  * Update Belgium holidays: add bank holidays
  * Update Canada holidays
  * Update Liechtenstein holidays: specify bank holidays
  * Update United Kingdom holidays
  * Add subdivision category holidays support
  * Add Barbados holidays
  * Add Iran holidays
  * Add Vanuatu holidays
  * Update Barbados holidays
  * Update Singapore holidays: add 2023 Polling Day
  * Update Slovenia holidays: add 2023 Solidarity Day
  * Update Vanuatu holidays
  * Update South Korea holidays
  * Update Taiwan holidays
  * Update Uruguay holidays
  * Add JULIAN_REVISED_CALENDAR calendar
  * Add Guatemala holidays
  * Update United Kingdom holidays: update certain holidays start years
  * Add HolidayBase methods for relative weekdays calculation
  * Add Brunei Darussalam holidays
  * Add Burkina Faso holidays
  * Add Cambodia holidays
  * Add Chad holidays
  * Add Columbus day to InternationalHolidays
  * Allow using ISO 639-2 (three-letter) language codes
  * Make Tynwald Day movable from 1992 onwards for Isle of Man
  * Use aware UTC datetimes internally
  * Introduce Asian holidays pre-calculated data
  * Add Belize holidays
  * Add Cameroon holidays
  * Add El Salvador holidays
  * Add Gabon holidays
  * Update Azerbaijan holidays: use custom Islamic calendar
  * Update Morocco holidays
  * Update Vatican City holidays
  * Introduce entity lazy loading
  * Add Algeria holidays
  * Update coverage upload process
  * Add Ecuador holidays
  * Add polib as a deploy process dependency
  * Introduce subdivision holidays methods
  * Refactor .po and .mo files generation
  * Update Andorra parish holidays
  * Add Costa Rica holidays
  * Update Portugal holidays
  * Fix NYSE New Year's Day observance calculation
  * Update Ireland holidays: St. Bridget's Day
  * Update Mexico holidays
  * Update Saudi Arabia holidays
  * Add functions for relative weekdays calculation
  * Use the built-in library for time zone functions
- Update Source and URL.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Fri Mar  3 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.20:
  * Add localization support, #827 (@arkid15r, @bkthomps, @dragoon)
  * Introduce `HolidayBase::_is_leap_year()`, #886 (@arkid15r)
  * Introduce `HolidayBase::_is_monday` - `HolidayBase::_is_sunday` helper
    methods, #841 (@arkid15r)
  * Change holiday name separator from ", " to "; ", #922 (@arkid15r)
  * Fix Hong Kong, #928 (@KJhellico)
  * Fix Islamic holidays calculation, #914 (@KJhellico)
  * Fix Thailand related changes coverage decrease, #942 (@arkid15r, @PPsyrius)
  * Improve Thailand holidays, #929 (@PPsyrius, @arkid15r, @KJhellico)
  * Update Australia holidays: fix 2020 QLD holidays, #923 (@arkid15r)
  * Update Bolivia holidays, #910 (@KJhellico)
  * Update Bosnia and Herzegovina holidays, #909 (@KJhellico)
  * Update Jamaica holidays, #913 (@KJhellico)
  * Update PR template, #960 (@arkid15r)
  * Update Poland holidays, add uk localization, #947 (@KJhellico)
  * Add International Women's Day for DE-MV, #936 (@alexanderschulze)
  * Add Marshall Islands (ISO-3666-1 code MH), #937 (@mborsetti)
  * Add Northern Mariana Islands (ISO-3666-2 code US-MP), #939 (@mborsetti)
  * ISO 3166-1 for US subdivisions, #941 (@mborsetti, @dr-prodigy)
  * Add Albania initial support #895 (@arkid15r)
  * Add Andorra initial support #896 (@arkid15r)
  * Add Bahrain initial support #888 (@arkid15r)
  * Add Montenegro initial support #897 (@arkid15r)
  * Add San Marino initial support #898 (@arkid15r)
  * Add Vatican City initial support #904 (@arkid15r)
  * Add Monaco holidays #877 (@KJhellico)
  * Migrate prophet.hdays countries #887 (@arkid15r)
  * Singapore holidays update #880 (@KJhellico)
  * PyMeeus for equinox and solstice calculation #828, #863 (Nalguedo)
  * Easter holidays refactoring and unification #803 (KJhellico)
  * Observed holidays calc optimizations #824 (KJhellico)
  * Special holidays refactoring for 13 countries #796 (arkid15r, KJhellico)
  * Support for Indonesia #787 (KJhellico)
  * Support for Pakistan #847 (KJhellico)
  * Support for Armenia #875 (KJhellico)
  * Korea renamed to South Korea #797 (arkid15r)
  * Azerbaijan: refactoring #859 (KJhellico)
  * Hong Kong: optimizations #786 (KJhellico)
  * Zambia: optimizations and refactoring #798 (KJhellico)
  * Vietnam: optimizations and refactoring #799 (KJhellico)
  * Malaysia: optimizations, refactoring and fixes #802, #858 (KJhellico)
  * New Zealand: optimizations and refactoring #836 (KJhellico)
  * Chile: optimizations #834 (KJhellico) + fixes #828 (Nalguedo)
  * Uruguay updates #809 (KJhellico)
  * Kazakhstan updates #829, #867 (KJhellico)
  * Canada fixes #811 (jasonjensen)
  * Nigeria updates #823 (KJhellico)
  * NY Stock Exchange updates #817, #853 (SnowX65, KJHellico)
  * New Zealand optimizazions #872 (KJhellico)
  * Madagascar updates #818 (KJhellico)
  * Paraguay updates #819 (KJhellico)
  * United Kingdom updates #840 (KJhellico)
  * South Africa: optimizations and updates #820, #848 (KJhellico)
  * US updates #857 (KJhellico)
  * Switzerland: optimizations, fix #821 (KJhellico)
  * Angola: optimizations, fix #822, #835 (KJhellico)
  * India updates #825 (KJhellico)
  * NY Stock Exchange updates #833 (SnowX65, KJhellico)
  * Hungary fixes #826 (KJhellico)
- Switch to GitHub source so the testsuite is included.
* Tue Oct 11 2022 pgajdos@suse.com
- really  update to version 0.16
- does not require python-six
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update Version 0.16
  Released September 16, 2022
  This release is dedicated to Queen Elizabeth II (21 April 1926 – 8 September 2022),
  who lived her long life as a monarch through 2 centuries, in both happy and difficult moments,
  with grace, dignity and an always inspiring strong sense of duty and warm heart.
  Goodbye "Lilibet", you have symbolically been a queen, a mother and a grandmother
  to a lot of us, and will be dearly missed.
  - Financial market support review, new method financial_holidays(..) #694 (dr-p)
  - Support for Moldova #695 (Thedand)
  - Support for Bolivia #679, #698 (kasya)
  - UK updates #702 (JPunter, violuke)
  - Australia updates #699 (Ryan-McCrory, dr-p)
  - Canada updates #710 (bkthomps)
  - New Zealand updates #708, #709 (dr-p, markhoneth)
  - NYSE updates #693, #696 (kasya)
- Update Version 0.15
  Released August 21, 2022
  - Added support for Python3.11 (dr-p)
  - Updated README - improved badges area (dr-p)
  - Support for Cuba #678 (bthompson, dr-p)
  - Typechecking implementation, first release (HolidayBase, utils, some sample countries) #661 (dimbleby)
  - Test coverage improvement #633 (akosfurton, dr-p)
  - Drop support for UK subdivisions as countries (England, Scotland..) (dr-p)
  - Drop support for IsleOfMan as UK subdivision (dr-p)
  - Drop support for PortugalExt (ie: extended Portugal) (dr-p)
  - US fixes #675 (arkid15r)
  - Colombia fixes & test improvements #676 (bkthomps)
  - Venezuela fixes & test improvements #677 (bkthomps)
  - Canada fixes #579 (dr-p, scubaandre)
  - Ukraine refactoring #681 (kasya)
  - Italy update #689 (g-gg, dr-p)
  - Bump pre-commit and setup-python actions #672, #682, #686, #688 (dr-p)
  - Doc example fix #685 (steakhutzeee, dr-p)
- Update Version 0.14.2
  Released June 5, 2022
  - Drop support for EOL Python 3.6 #328 (hugovk, dr-p)
  - Package review #662 (dimbleby)
  - Added financial markets support: ECB and NYSE, list_supported_financial() method (dr-p)
  - Support for NY Stock Exchange #651, #458 (nadime, dr-p)
  - Support for Malta #612, #630 (rafelbev)
  - Support for Madagascar #656 (fav007)
  - Support for Cyprus #410, #665 (digidestination, avnigo)
  - Ireland as standalone country #636, #639 (TeoTN, dr-p, javicalle)
  - Australia fixes #631 (jeremychrimes)
  - Singapore updates #652 (mborsetti)
  - Saudi Arabia fixes #642 (OsaydAbdu)
  - Spain fixes #634 (javicalle)
  - US fixes #648 (dashdrum)
  - Greece fixes #659 (tudorvaran)
  - India doc fixes #657 (dr-p)
  - Poland fix #663 (kfsz)
- Update Version 0.13
  Released February 15, 2022
  - New subdivision parameter (subdiv), prov/state deprecation #608, #597, #374 (mborsetti)
  - CountryHoliday class deprecation (replaced by country_holidays) (mborsetti, dr-p)
  - Sphinx documentation #600, #601, #602 (mborsetti)
  - Integration of mypy in pre-commit #620 (mborsetti)
  - Wrong year expansion fix #586, #606, #625 (mborsetti, TeejMonster, dr-p)
  - Refactoring / cleanups / code and naming reviews (mborsetti)
  - Support for Uzbekistan #593 (slako, dr-p)
  - Italy fixes/improvements #617, #614 (energywave)
  - Spain improvements #580, #603, #624 (gtrabanco, delaosa, dr-p)
  - UAE updates (weekend change) #609 (marcomasulli, dr-p)
  - India updates #548 (mborsetti)
  - US fixes #594, #595, #619 (apicht, SudoRob, dr-p)
  - UK fixes #587 (mborsetti)
  - Russia fixes #582 (Enzokot)
  - Type hints fixes #589 (mborsetti)
- Update Version 0.12
  Released January 4, 2022
  - Copyright update 2022
  - Sphinx documentation stub (mborsetti, dr-p)
  - Support for Kazakhstan #534 (chiuczek, intelliHugh)
  - Support for Azerbaijan #540 (eldar-mustafayev)
  - Support for Tunisia #543 (ihebski)
  - Support for Taiwan #547 (ifurther)
  - Support for North Macedonia #570 (tserekh)
  - Support for Ethiopia #558 (tedtad, dr-p)
  - Travis CI removal #557 (mborsetti, dr-p)
  - CD/CI tests - Pypi versions review (dr-p)
  - More useful __repr__ and __str__ #360 (dr-p, kootenpv, d33tah)
  - Drop support for Czech (ie: misspelled Czechia) (dr-p)
  - Drop support for Polish (ie: misspelled Poland) (dr-p)
  - Drop support for Slovak (ie: misspelled Slovakia) (dr-p)
  - Test coverage improvement (dr-p)
  - "country" property moved to class attributes #573 (dr-p, madphysicist)
  - Date slices support fix #529, #530 (justinwaf, mborsetti, dr-p)
  - Dictionary changed during iteration fix #569 (mborsetti)
  - Doc fixes #549 (canute24)
  - UK standalone states deprecation #566 (dr-p)
  - Venezuela ISO code + other fixes #567, #576 (Skatox, dr-p, antusystem)
  - Canada updates and test review #533, #536 (cturra)
  - US updates and fixes #537, #559, #578 (khawley, evohnave, amelkiy, dr-p)
  - India fixes #553, #554, #539 (canute24, dr-p)
  - Spain fixes #555 (tserekh)
  - Italy fixes #546 (dr-p, rtraverso86)
  - Korea fixes #535 (0xF4D3C0D3)
  - Colombia fixes #564 (jahirfiquitiva)
- Update to Version 0.11.3.1
  Released September 29, 2021
  - Support for Zambia #495, #496 (engineervix)
  - Support for Uruguay #489, #490, #491, #492, #493 (jemazzeo, dr-p)
  - Support for Lesotho #512 (pietervdw115)
  - Support for Namibia #513 (pietervdw115)
  - Support for Swaziland #514 (pietervdw115)
  - Support for Zimbabwe #517 (pietervdw115)
  - Support for China #515 (tserekh)
  - Refactor lunisolar and islamic calendar #524 (mborsetti)
  - Removed six dependency #494 (mborsetti)
  - Type hinting #497, #498 (mborsetti)
  - Malaysia refactoring & updates #524 (mborsetti)
  - New Zealand updates #499 (36wish)
  - USA, Angola fixes (jusce17)
  - Kenya updates #502 (MainaKamau92)
  - Korea updates #508 (0xF4D3C0D3, dr-p)
  - Bulgaria updates #509 (BasakUlker, dr-p)
  - Australia updates #516 (cmckeague)
  - South Africa updates (lispwarez, dr-p)
  - Canada updates #457 (dr-p)
  - PRTE (PortugalExt) fix #520 (dr-p)
  - Norway updates #472 (dr-p)
  - Chile updates #473 (dr-p)
  - Australia updates #525 (jeremychrimes)
  - README iso codes typo / improvements #520 (dr-p)
  - .gitattributes fix #522 (mborsetti)
-Update to Version 0.11.2
  Released July 18, 2021
  - Support for Venezuela #470 (antusystem, dr-p)
  - Support for Botswana #477 (pietervdw115)
  - Support for Malaysia #466 (jusce17) *needs improvement*
  - Poland fix #464 (m-ganko)
  - Singapore updates for 2022 #456 (mborsetti)
  - US updates #474, #488 (ChristianAlexander, jusce17)
  - NG updates #486 (pietervdw115)
  - UK updates #487 (orrock, dr-p)
  - .gitignore fix #462 (TheLastProject)
  - Pre-commit v.2.0.3 (dr-p)
* Mon May  3 2021 Matej Cepl <mcepl@suse.com>
- Use %%pytest macro
* Mon May  3 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.11.1
  * Support for Saudi Arabia
  * Support for Curacao
  * Support for Jamaica
  * Support for Georgia
  * init.py flake8 issue fix
  * Korea 2020 fix
  * Singapore fix for multi-year
  * Israel fix
  * Japan fix
  * Serbia fix
  * United Kingdom get_list fix
  * Singapore fix for multi-year
  * Fixed holidays pickling
- remove:
  - disable-lag-baomer.patch
  - disable-flake.patch
* Mon Feb  8 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.10.5.2
  * Dropped support for Python 2 (dr-p)
  * Removed convertdate<=2.2.0 constraint (dr-p)
  * Travis CI integration review (dr-p)
  * Support for Mozambique (jusce17)
  * Angola fixes (jusce17)
  * Portugal localized holidays (jusce17)
  * Disable year expansion on name search #411 (giladmaya)
  * Israel fixes (new convertdate version) #407 (giladmaya)
  * Ireland fixes (ISO-2 code, partial split from UK) #417 (javicalle)
  * Honduras fix (ISO-2 code) #405 (dr-p, agorajek)
- had to disable lag-boamer support due lack of official resource for it
  via disable-lag-baomer.patch
* Mon Jan  4 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.10.4
  * Dropped support for Python 3.5
  * Support for Djibouti (Abdisamade)
  * Support for United Arab Emirates (marcomasulli, mborsetti)
  * Support for Chile (mborsetti, dr-p)
  * Support for Angola (jusce17, pietervdw115, dr-p)
  * Support for Malawi (pietervdw115)
  * Support for Bangladesh (dr-p, tasnimislam)
  * Korea fixes (MYUNGJE, dr-p, hiddentrap)
  * Australia 2020 fix (bencollerson, trauty-is-me)
  * Croatia fixes and updates (jangrg, mborsetti, dr-p)
  * United States fixes (raffg, bgmiles, dr-p)
  * UK fixes/improvements (dr-p, richard-kunert, emreay-)
  * Russia fixes (tserekh)
  * Ireland fixes (chiuczek)
  * Spain observed holidays fix (sermayoral)
  * South Africa observed holidays fix (pietervdw115)
  * France fix (mborsetti)
  * Mexico fix (mborsetti)
  * Singapore 2022 fix (mborsetti)
  * Japan 1990-1993 fixes (sakurai-youhei)
  * Fix on occasional pop_named exception (mborsetti)
  * convertdate fallback if hijri-converter not available (mborsetti, dr-p)
  * enabled Travis tests for python3.9 (mborsetti)
  * added flake8 to unittests (mborsetti)
- disable failing code style test case (adding disable-flake.patch)
* Mon Jul 27 2020 Adrian Schröter <adrian@suse.de>
- Update to version 0.10.3
  Released July 15, 2020
- Added get_named(substring) method to retrieve holidays by name (dr-p)
- Added pop_named(substring) method to pop specific holiday/s by name (samtregar, dr-p)
- Support for Burundi (bmwachajr)
- Support for Latvia (rolandinsh)
- Support for Romania (dorianm)
- Spain fix (dr-p)
- Netherlands fix (RooieRakkert)
- Switzerland fixes (cgrigis)
- Germany fix (MikeTsenatek)
- Added korean_cal attribute to Korea and Vietnam (seriousran, pelennor)
- United States fixes (patrick-nicholson, dr-p)
- Singapore fixes + 2021 holidays (mborsetti)
  Version 0.10.2
  ==============
  Released April 13, 2020
- Support for Spain (piliamaurizio, jbroudou, dr-p, gerardo15)
- Support for Turkey (cemkaragozlu)
- Support for Korea (1kko, dr-p)
- Support for Vietnam (1kko, dr-p)
- Support for Morocco (abensrhir, dr-p)
- Mexico fix (Rosi2143, dr-p)
- Croatia fix (sebojanko, dr-p)
- US Georgia fix (jbroudou, dr-p)
- Austria province ISO3166-2 adoption (jbroudou, dr-p)
- Portugal typos & name fixes (reinaldoramosarxi)
- US MLK renamed (snoopyjc, dr-p)
- ISO-3 codes export fix (dr-p)
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.10.1
  * Project structure refactoring (MaxHaertwig, dr-p)
  * Added support for Python3.8 (dr-p)
  * Dropped support for pypy and Python3.4, welcome back pypy3 (dr-p)
  * Fully reviewed Travis CI integration (dr-p)
  * Added 3-digit country ISO codes (MaxHaertwig)
  * Support for Paraguay (dr-p, sfeliu)
  * Support for Israel (giladmaya, dr-p)
  * Support for Egypt (gaberm)
  * Support for Serbia (kosugor)
  * Support for Singapore (mborsetti)
  * README.rst fixes / sync
  * Brazil-Parana support (dr-p, jbroudou)
  * Japan fixes (dr-p, thophan92, saurabh3896)
  * Canada, Spain, US fixes (jbroudou)
  * Belarus fix (mpolyakovsky)
* Fri Jan 17 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.9.12:
  * Support for Nigeria (ioluwayo)
  * Support for India - Telangana (kiranbeethoju, dr-p)
  * Support for Dominican Republic (gabmartinez)
  * Support for Nicaragua (CARocha)
  * Code refactoring, bugfixes (vlt)
  * Add method to list all supported countries (fabaff)
  * Germany bugfixes (bitraten)
  * Correctly handle United Kingdom "May Day" holiday in 2020 - #219 (robfraz)
  * Hungary fixes (gypapp)
  * Chile test fixes (rpanai)
  * Italy fixes (jokerigno, sixbladeknife)
  * Other minor fixes
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.11:
  - Added Japanese holidays for new Emperor (kokinamura)
  - Fixed Australian Canberra day holiday (explodingdinosaurs, dr-p)
  - Added support for Estonian holidays (RaulVS14)
  - Added support for Iceland and Kenya (justinasfour04)
  - Added support for Aruba (orson1282)
  - Added support for Hong Kong (polifaces)
  - Added support for Peru (manuelvalino)
  - Switzerland fixes (spasche)
  - Croatia fix (pave121, dr-p)
  - Polish deprecation: replaced by Poland (dr-p)
  - Czech(ia) - Slovak(ia) fixes (dr-p)
  - Allow passing years to CountryHoliday (mr.shu)
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Remove conjecture from description and ensure neutrality.
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.10:
  - Added Lithuanian holidays support (GiedriusMauza)
  - Added Luxembourgish holidays (theFeverDog)
  - Added Russian holidays (mshinkareva)
  - Added Bulgarian holidays (pavelsof)
  - Holidays in date range (elln2)
  - German holidays updates (MrtnBckr, alexanderschulze)
  - South African holidays updates (nickyspag)
  - Australian holidays updates (itssimon)
- Run tests
- Run fdupes
- Fix URL
* Tue Mar 12 2019 Adrian Schröter <adrian@suse.de>
- initial package of version 0.9.9
